@@ -185,16 +185,23 @@
 	(font-size . -2)
 	(Y-offset . ,ly:side-position-interface::y-aligned-side)
 	(side-axis . ,Y)
-	(X-offset . ,ly:self-alignment-interface::x-aligned-on-self)
-	(self-alignment-X . 1)
+	(X-offset . ,(ly:make-simple-closure
+		      `(,+
+			,(ly:make-simple-closure
+			  (list ly:break-alignment-align-interface::self-align-callback))
+			,(ly:make-simple-closure
+			  (list ly:self-alignment-interface::x-aligned-on-self)))))
 
+	(self-alignment-X . 1)
+	(break-align-symbol . left-edge)
 	(meta .
 	      ((class . Item)
 	       (interfaces . (side-position-interface
 			      text-interface
+			      break-alignment-align-interface
 			      self-alignment-interface
 			      font-interface
-			      break-aligned-interface))))
+			      ))))
 	))
 
     (BassFigure
@@ -796,6 +803,17 @@
 		 (interfaces . (line-interface
 				tuplet-bracket-interface))))))
 
+
+    (LyricExtender
+     . (
+	(stencil . ,ly:lyric-extender::print)
+	(thickness . 0.8) ; line-thickness
+	(minimum-length . 1.5)
+	(Y-extent . (0 . 0))
+	(meta . ((class . Spanner)
+		 (interfaces . (lyric-interface
+				lyric-extender-interface))))))
+
     (LyricHyphen
      . (
 	(thickness . 1.3)
@@ -814,18 +832,8 @@
 				lyric-hyphen-interface
 				spanner-interface))))))
 
-    (LyricExtender
-     . (
-	(stencil . ,ly:lyric-extender::print)
-	(thickness . 0.8) ; line-thickness
-	(minimum-length . 1.5)
-	(Y-extent . (0 . 0))
-	(meta . ((class . Spanner)
-		 (interfaces . (lyric-interface
-				lyric-extender-interface))))))
-
     (LyricSpace
-     . ((minimum-distance . 0.3)
+     . ((minimum-distance . 0.45)
 	(springs-and-rods . ,ly:hyphen-spanner::set-spacing-rods)
 	(padding . 0.0)
 	(Y-extent . #f)
@@ -1052,12 +1060,10 @@
     (PaperColumn
      . (
 	(axes . (0))
-
 	(before-line-breaking . ,ly:paper-column::before-line-breaking)
 	;; (stencil . ,ly:paper-column::print)
 	(X-extent . ,ly:axis-group-interface::width)
 	
-
 	;; debugging
 	;;		         (font-size . -6) (font-name . "sans") (Y-extent . #f)
 	(meta . ((class . Paper_column)
@@ -1066,14 +1072,13 @@
 				spaceable-grob-interface))))))
 
     (ParenthesesItem
-     . (
-	(stencil . ,parentheses-item::print)
+     . ((stencil . ,parentheses-item::print)
 	(font-size . -6)
 	(padding . 0.2)
 	(meta . ((class . Item)
 		 (interfaces . (parentheses-interface font-interface))))
-	
-	      ))
+	))
+    
     (PhrasingSlur
      . ((details . ,default-slur-details)
 	(control-points . ,ly:slur::calc-control-points)
@@ -1156,11 +1161,12 @@
      . (
 	(stencil . ,ly:text-interface::print)
 	(X-offset . ,(ly:make-simple-closure
-		      `(,+ ,(ly:make-simple-closure
-			     `(,ly:self-alignment-interface::x-aligned-on-self))
-			   ,(ly:make-simple-closure
-			     `(,ly:self-alignment-interface::centered-on-x-parent)))
-		      ))
+		      `(,+
+			,(ly:make-simple-closure
+			  (list ly:break-alignment-align-interface::self-align-callback))
+			,(ly:make-simple-closure
+			  (list ly:self-alignment-interface::x-aligned-on-self)))))
+
 	(Y-offset . ,ly:side-position-interface::y-aligned-side)
 	(self-alignment-X . 0)
 	(direction . ,UP)
@@ -1168,10 +1174,12 @@
 	(font-size . 2)
 	(baseline-skip . 2)
 	(break-visibility . ,end-of-line-invisible)
+	(break-align-symbol . staff-bar)
 	(padding . 0.8)
 	(meta . ((class . Item)
 		 (interfaces . (text-interface
 				side-position-interface
+				break-alignment-align-interface
 				font-interface
 				mark-interface
 				self-alignment-interface))))))
@@ -1443,7 +1451,8 @@
 	(stencil . ,ly:stem-tremolo::print)
 	(X-extent . #f)
 	(slope . ,ly:stem-tremolo::calc-slope)
-	(beam-width . 1.6) ; staff-space
+	(beam-width . ,ly:stem-tremolo::calc-width) ; staff-space
+        (style . ,ly:stem-tremolo::calc-style)
 	(beam-thickness . 0.48) ; staff-space
 	(meta . ((class . Item)
 		 (interfaces . (stem-tremolo-interface))))))
@@ -1570,7 +1579,7 @@
 	(stencil . ,ly:text-interface::print)
 	(Y-offset . ,ly:staff-symbol-referencer::callback)
 	(font-size . -2)
-	(stem-attachment . (1.0 . 1.35))
+	(stem-attachment . (0.0 . 1.35))
 	(font-series . bold)
 	(meta . ((class . Item)
 		 (interfaces
