@@ -605,7 +605,7 @@ output = {
 
 		PRINTFILENAME: '''
 @html
-<a href="%(filename)s">
+<a href="%(base)s">
 @end html
 @file{%(filename)s}
 @html
@@ -1068,7 +1068,7 @@ class Lilypond_snippet (Snippet):
 
 	def png_is_outdated (self):
 		base = self.basename ()
-		ok = self.ly_is_outdated ()
+		ok = not self.ly_is_outdated ()
 		if global_options.format in (HTML, TEXINFO):
 			ok = ok and os.path.exists (base + '.eps')
 
@@ -1076,7 +1076,7 @@ class Lilypond_snippet (Snippet):
 			if ok:
 				page_count = ps_page_count (base + '.eps')
 			
-			if page_count == 1:
+			if page_count <= 1:
 				ok = ok and os.path.exists (base + '.png')
 			elif page_count > 1:
 				for a in range (1, page_count + 1):
@@ -1375,7 +1375,7 @@ def process_snippets (cmd, ly_snippets, texstr_snippets, png_snippets):
 	ly_names = filter (lambda x: x,
 			   map (Lilypond_snippet.basename, ly_snippets))
 	texstr_names = filter (lambda x: x,
-			   map (Lilypond_snippet.basename, texstr_snippets))
+			       map (Lilypond_snippet.basename, texstr_snippets))
 	png_names = filter (lambda x: x,
 			    map (Lilypond_snippet.basename, png_snippets))
 
@@ -1385,6 +1385,9 @@ def process_snippets (cmd, ly_snippets, texstr_snippets, png_snippets):
 				    be_verbose=global_options.verbose, 
 				    progress_p= 1)
 
+        if global_options.format in (HTML, TEXINFO):
+		cmd += ' --format png '
+ 
 	# UGH
 	# the --process=CMD switch is a bad idea
 	# it is too generic for lilypond-book.
@@ -1521,7 +1524,8 @@ def do_process_cmd (chunks, input_name):
 	map (Lilypond_snippet.write_ly, ly_outdated)
 	progress ('\n')
 
-	if ly_outdated:
+        outdated = png_outdated + texstr_outdated + ly_outdated
+	if outdated:
 		progress (_ ("Processing..."))
 		progress ('\n')
 		process_snippets (global_options.process_cmd, ly_outdated, texstr_outdated, png_outdated)
