@@ -24,6 +24,15 @@ elif os.path.exists (os.path.join (datadir, 'share/lilypond/current/')):
 sys.path.insert (0, os.path.join (datadir, 'python'))
 
 
+# dynamic relocation, for GUB binaries.
+bindir = os.path.split (sys.argv[0])[0]
+
+for prefix_component in ['share', 'lib']:
+	datadir = os.path.abspath (bindir + '/../%s/lilypond/current/python/' % prefix_component)
+	sys.path.insert (0, datadir)
+
+
+
 import musicxml
 import musicexp
 import lilylib as ly
